@@ -49,7 +49,7 @@ class BaseScript(ArgumentParserScript):
 
     name = ""  # optional, may be needed for some applications
     flow_id_required = False  # if True, script can only run in the context of a flow_id
-    children_tags = None
+    children_tags = None  # extra tags added to children
     default_project_id = None  # If None, autodetect (see shub_workflow.utils.resolve_project_id)
 
     def __init__(self):
@@ -66,19 +66,20 @@ class BaseScript(ArgumentParserScript):
         self.__flow_tags.append(tag)
         self.add_job_tags(tags=[tag])
 
-    def set_flow_id(self, args, default=None):
-        self._flow_id = args.flow_id or self._get_flowid_from_tags() or default
-        if self.flow_id_required:
-            assert not self.flow_id_required or self.flow_id, "Could not detect flow_id. Please set with --flow-id."
-        if self.flow_id:
-            tags = [f"FLOW_ID={self.flow_id}"]
-            if self.name:
-                tags.append(f"NAME={self.name}")
-            self.add_job_tags(tags=tags)
+    @staticmethod
+    def generate_flow_id():
+        raise NotImplementedError("generate_flow_id() must be implemented if flow_id_required is True.")
 
-    @property
-    def flow_id(self):
-        return self._flow_id
+    def set_flow_id_name(self, args):
+        flowid_from_tag, name_from_tag = self._get_flowid_name_from_tags()
+        self.flow_id = flowid_from_tag or args.flow_id
+        if not self.flow_id and self.flow_id_required:
+            self.flow_id = self.generate_flow_id()
+        tags = [f"FLOW_ID={self.flow_id}"]
+        self.name = name_from_tag or args.name or self.name
+        if self.name:
+            tags.append(f"NAME={self.name}")
+        self.add_job_tags(tags=tags)
 
     def add_argparser_options(self):
         self.argparser.add_argument(
@@ -87,7 +88,7 @@ class BaseScript(ArgumentParserScript):
         self.argparser.add_argument("--name", help="Script name.")
         self.argparser.add_argument("--flow-id", help="If given, use the given flow id.")
         self.argparser.add_argument(
-            "--tag",
+            "--children-tag",
             help="Additional tag added to the scheduled jobs. Can be given multiple times.",
             action="append",
             default=self.children_tags or [],
@@ -103,8 +104,7 @@ class BaseScript(ArgumentParserScript):
         if not self.project_id:
             self.argparser.error("Project id not provided.")
 
-        self.name = args.name or self.name
-        self.set_flow_id(args)
+        self.set_flow_id_name(args)
         return args
 
     def get_project(self, project_id=None):
@@ -138,7 +138,7 @@ class BaseScript(ArgumentParserScript):
         """
         metadata = self.get_job_metadata(jobkey)
         if metadata:
-            return dict(metadata.list()).get("tags", [])
+            return dict(self._list_metadata(metadata)).get("tags", [])
         return []
 
     def get_keyvalue_job_tag(self, key, tags):
@@ -151,6 +151,16 @@ class BaseScript(ArgumentParserScript):
     def _update_metadata(metadata, data):
         metadata.update(data)
 
+    @staticmethod
+    @dash_retry_decorator
+    def _list_metadata(metadata):
+        return metadata.list()
+
+    @staticmethod
+    @dash_retry_decorator
+    def _get_metadata_key(metadata, key):
+        return metadata.get(key)
+
     def add_job_tags(self, jobkey=None, tags=None):
         """If jobkey is None, add tags to own list of tags.
         """
@@ -169,15 +179,17 @@ class BaseScript(ArgumentParserScript):
                 if metadata:
                     self._update_metadata(metadata, {"tags": job_tags})
 
-    def _get_flowid_from_tags(self, jobkey=None):
+    def _get_flowid_name_from_tags(self, jobkey=None):
         """If jobkey is None, get flowid from own tags
         """
         tags = self.get_job_tags(jobkey)
-        return self.get_keyvalue_job_tag("FLOW_ID", tags)
+        flow_id = self.get_keyvalue_job_tag("FLOW_ID", tags)
+        name = self.get_keyvalue_job_tag("NAME", tags)
+        return flow_id, name
 
     def _make_children_tags(self, tags):
         tags = tags or []
-        tags.extend(self.args.tag)
+        tags.extend(self.args.children_tag)
         if self.flow_id:
             tags.append(f"FLOW_ID={self.flow_id}")
             if self.name:
@@ -248,7 +260,7 @@ class BaseScript(ArgumentParserScript):
         project_id = jobkey.split("/", 1)[0]
         project = self.get_project(project_id)
         job = project.jobs.get(jobkey)
-        if job.metadata.get("state") in ("running", "pending"):
+        if self._get_metadata_key(job.metadata, "state") in ("running", "pending"):
             return True
         return False
 
@@ -257,8 +269,8 @@ class BaseScript(ArgumentParserScript):
         Checks whether a job is running. if so, return close_reason. Otherwise return None.
         """
         metadata = self.get_job_metadata(jobkey)
-        if metadata.get("state") == "finished":
-            return metadata.get("close_reason")
+        if self._get_metadata_key(metadata, "state") == "finished":
+            return self._get_metadata_key(metadata, "close_reason")
 
     @dash_retry_decorator
     def finish(self, jobkey=None, close_reason=None):
