@@ -1,6 +1,7 @@
 import logging
 import json
 import os
+import hashlib
 from typing import Optional
 from traceback import format_tb
 
@@ -11,6 +12,12 @@ logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 
+def hashstr(text):
+    u = hashlib.sha1()
+    u.update(text.encode("utf8"))
+    return u.hexdigest()
+
+
 def resolve_project_id(project_id=None) -> Optional[int]:
     """
     Gets project id from following sources in following order of precedence:
